# PIIEntityTypes


## Enum

* `CREDIT_CARD` (value: `'CREDIT_CARD'`)

* `CRYPTO` (value: `'CRYPTO'`)

* `DATE_TIME` (value: `'DATE_TIME'`)

* `EMAIL_ADDRESS` (value: `'EMAIL_ADDRESS'`)

* `IBAN_CODE` (value: `'IBAN_CODE'`)

* `IP_ADDRESS` (value: `'IP_ADDRESS'`)

* `NRP` (value: `'NRP'`)

* `LOCATION` (value: `'LOCATION'`)

* `PERSON` (value: `'PERSON'`)

* `PHONE_NUMBER` (value: `'PHONE_NUMBER'`)

* `MEDICAL_LICENSE` (value: `'MEDICAL_LICENSE'`)

* `URL` (value: `'URL'`)

* `US_BANK_NUMBER` (value: `'US_BANK_NUMBER'`)

* `US_DRIVER_LICENSE` (value: `'US_DRIVER_LICENSE'`)

* `US_ITIN` (value: `'US_ITIN'`)

* `US_PASSPORT` (value: `'US_PASSPORT'`)

* `US_SSN` (value: `'US_SSN'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


